==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway.md <==
# AmazonVpcCustomerGateway


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')
```



| Illustration | AmazonVpcCustomerGateway | AmazonVpcCustomerGatewayCard | AmazonVpcCustomerGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway.png) | ![illustration for AmazonVpcCustomerGateway](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway.Local.png) | ![illustration for AmazonVpcCustomerGatewayCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGatewayCard.Local.png) | ![illustration for AmazonVpcCustomerGatewayGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGatewayGroup.Local.png) |




## AmazonVpcCustomerGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGateway
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGateway('AmazonVpcCustomerGateway', 'Amazon Vpc Customer Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGateway
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGateway('AmazonVpcCustomerGateway', 'Amazon Vpc Customer Gateway', 'an optional tech label')
@enduml
```

## AmazonVpcCustomerGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGatewayCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGatewayCard('AmazonVpcCustomerGatewayCard', 'Amazon Vpc Customer Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGatewayCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGatewayCard('AmazonVpcCustomerGatewayCard', 'Amazon Vpc Customer Gateway Card', 'an optional description')
@enduml
```

## AmazonVpcCustomerGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGatewayGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGatewayGroup('AmazonVpcCustomerGatewayGroup', 'Amazon Vpc Customer Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGatewayGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGatewayGroup('AmazonVpcCustomerGatewayGroup', 'Amazon Vpc Customer Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway.md <==
# AmazonVpcCustomerGateway


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')
```



| Illustration | AmazonVpcCustomerGateway | AmazonVpcCustomerGatewayCard | AmazonVpcCustomerGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway.png) | ![illustration for AmazonVpcCustomerGateway](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway.Local.png) | ![illustration for AmazonVpcCustomerGatewayCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGatewayCard.Local.png) | ![illustration for AmazonVpcCustomerGatewayGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGatewayGroup.Local.png) |




## AmazonVpcCustomerGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGateway
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGateway('AmazonVpcCustomerGateway', 'Amazon Vpc Customer Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGateway
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGateway('AmazonVpcCustomerGateway', 'Amazon Vpc Customer Gateway', 'an optional tech label')
@enduml
```

## AmazonVpcCustomerGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGatewayCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGatewayCard('AmazonVpcCustomerGatewayCard', 'Amazon Vpc Customer Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGatewayCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGatewayCard('AmazonVpcCustomerGatewayCard', 'Amazon Vpc Customer Gateway Card', 'an optional description')
@enduml
```

## AmazonVpcCustomerGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGatewayGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGatewayGroup('AmazonVpcCustomerGatewayGroup', 'Amazon Vpc Customer Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcCustomerGatewayGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcCustomerGateway')

' renders the element
AmazonVpcCustomerGatewayGroup('AmazonVpcCustomerGatewayGroup', 'Amazon Vpc Customer Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
